============
Front Matter
============

Information about the dogpile.cache project.

Project Homepage
================

dogpile.cache is hosted on `Bitbucket <http://bitbucket.org>`_ - the lead project page is at https://bitbucket.org/zzzeek/dogpile.cache.  Source code is tracked here using Git.

.. versionchanged:: 0.5.0 Moved source repository to git.

Releases and project status are available on Pypi at http://pypi.python.org/pypi/dogpile.cache.

The most recent published version of this documentation should be at http://dogpilecache.readthedocs.org.

Installation
============

Install released versions of dogpile.cache from the Python package index with `pip <http://pypi.python.org/pypi/pip>`_ or a similar tool::

    pip install dogpile.cache

Installation via source distribution is via the ``setup.py`` script::

    python setup.py install

Community
=========

dogpile.cache is developed by `Mike Bayer <http://techspot.zzzeek.org>`_, and is
loosely associated with the `Pylons Project <http://www.pylonsproject.org/>`_.
As dogpile.cache's usage increases, it is anticipated that the Pylons mailing list and IRC channel
will become the primary channels for support.

Bugs
====

Bugs and feature enhancements to dogpile.cache should be reported on the `Bitbucket
issue tracker
<https://bitbucket.org/zzzeek/dogpile.cache/issues?status=new&status=open>`_.   If you're not sure
that a particular issue is specific to either dogpile.cache or `dogpile.core <https://bitbucket.org/zzzeek/dogpile.core>`_, posting to the dogpile.cache
tracker is likely the better place to post first.

* `dogpile.cache issue tracker <https://bitbucket.org/zzzeek/dogpile.cache/issues?status=new&status=open>`_ (post here if unsure)
* `dogpile.core issue tracker <https://bitbucket.org/zzzeek/dogpile.core/issues?status=new&status=open>`_

